pub struct BusyInfo {
pub pid: u32,
pub cmd: String,
pub cwd: PathBuf,
pub source: BusySource,
}Expand description
Information about a single process holding a worktree busy.
Fields
pid: u32cmd: Stringcwd: PathBufFor lockfile sources, this is the worktree path (the process’s actual cwd is unknown). For process-scan sources, this is the process’s canonicalized cwd.
source: BusySourceTrait Implementations