resolve_all

Function resolve_all 

pub fn resolve_all(
    inputs: &[String],
    lookup_mode: Option<&str>,
) -> Result<Vec<PlanEntry>>
Resolve a list of user inputs against the main repository.

Inputs may be branch names, worktree directory names, or filesystem paths. Anything that does not resolve becomes a PlanEntry::Unresolved.