Module launchers

Module launchers 

Modules

detached
Terminal launcher implementations.
foreground
iterm
tmux
wezterm
zellij

Functions

keep_shell_after
Wrap a command line so that, after it exits, the pane/window/tab keeps a fresh interactive login shell instead of closing.