Module worktree

Module worktree 

Structs

DeleteFlags
Flags that apply uniformly to every target in a batch.

Enums

DeletionOutcome
Outcome of attempting to delete a single worktree.

Functions

create_worktree
Create a new worktree with a feature branch.
delete_worktree
Delete a worktree by branch name, worktree directory name, or path.
sync_worktree
Sync worktree with base branch.