Module session

Module session 

Structs

SessionMetadata
Session metadata.

Functions

chrono_now_iso_pub
Public accessor for the ISO timestamp function.
claude_native_session_exists
Check if a Claude native session exists for the given worktree path.
delete_session
Delete all session data for a branch.
get_session_dir
Get the session directory for a specific branch.
get_sessions_dir
Get the base sessions directory. Falls back to legacy Python path if the new path doesn’t exist.
list_sessions
List all saved sessions.
load_context
Load context information for a branch.
load_session_metadata
Load session metadata for a branch.
save_context
Save context information for a branch.
save_session_metadata
Save session metadata for a branch.