pub fn is_branch_merged(
feature_branch: &str,
base_branch: &str,
repo: Option<&Path>,
) -> boolExpand description
Check if a branch has been merged into the base branch.
Uses git branch --merged <base> and checks if the feature branch is in the list.