pub fn render_refusal(
branch_display: &str,
hard: &[BusyInfo],
soft: &[BusyInfo],
) -> StringExpand description
Render the user-facing refusal text. Empty inputs in both vectors is a programming error (caller should not have refused) but is rendered as an empty string for safety.