pub fn set_value(root: &mut Value, key: ConfigKey, value: Value) -> Result<()>Expand description
Set key to value inside root, creating intermediate objects as
needed. Errors only if an intermediate path collides with a non-object
(the only way this can happen is if the file was hand-edited).