gw run <cmd> โ fan a command out across all worktrees in scope.
Functions
- run_
in_ scope - run_
in_ scope_ to_ writer - Returns the last non-zero exit code observed (or 0 if all succeeded).
In parallel mode (
jobs > 1),continue_on_error = falseaborts at batch boundaries โ siblings already started in the same batch run to completion.