Structs
- RmFlags
- Flags that apply uniformly to every target in a batch.
Enums
- Deletion
Outcome - Outcome of attempting to delete a single worktree.
Functions
- create_
worktree - Create a new worktree with a feature branch.
- delete_
worktree - Delete a worktree by branch name, worktree directory name, or path.