Structs
- Session
Metadata - Session metadata.
Functions
- chrono_
now_ iso_ pub - Public accessor for the ISO timestamp function.
- claude_
native_ session_ exists - Check if a Claude native session exists for the given worktree path.
- delete_
session - Delete all session data for a branch.
- get_
session_ dir - Get the session directory for a specific branch.
- get_
sessions_ dir - Get the base sessions directory. Falls back to legacy Python path if the new path doesn’t exist.
- list_
sessions - List all saved sessions.
- load_
context - Load context information for a branch.
- load_
session_ metadata - Load session metadata for a branch.
- save_
context - Save context information for a branch.
- save_
session_ metadata - Save session metadata for a branch.